==> makeen-expressionengine-0.0.51.tgz: package/src/compiler/parts/switchPartData.ts <==
import { expressionPart } from "./expressionPart";
import expressionData from "../../expressionData";
import { utils } from "../utils";
import { outputVariables } from "../../utils/outputVariables";
export interface switchExpressionPart {
    key: expressionPart;
    value: expressionPart;
}
export class switchPartData {

    private cases: switchExpressionPart[] = [];

    public get Cases(): switchExpressionPart[] {
        return this.cases;
    }

    private defaultValue!: expressionPart;

    public get DefaultValue(): expressionPart {
        return this.defaultValue;
    }
    public set DefaultValue(value: expressionPart) {
        this.defaultValue = value;
    }

    private nullValue!: expressionPart;

    public get NullValue(): expressionPart {
        return this.nullValue;
    }
    public set NullValue(value: expressionPart) {
        this.nullValue = value;
    }

    public forValue(expressionData: expressionData, value: Object, resolved: outputVariables): Object | undefined {
        resolved.resolved = true;
        let resultingExpression!: expressionPart;
        if ((value == null)) {
            if ((this.nullValue != null)) {
                resultingExpression = this.nullValue;
            }
            else if ((this.defaultValue != null)) {
                resultingExpression = this.defaultValue;
            }

        }
        else {
            let matched!: expressionPart;
            this.cases.forEach((keyPart) => {
                let subResolved: outputVariables = new outputVariables();
                const reKey = (keyPart as switchExpressionPart).key;
                let key: Object = reKey.resolve(expressionData, subResolved, undefined) as Object;
                if ((subResolved.resolved
                    && ((key != null)
                        && utils.compare(key, value, '=')))) {
                    matched = keyPart.key;
                }
            });

            if ((matched != null)) {
                resultingExpression = this.cases.find((f) => f.key === matched)?.value as expressionPart;
            }
            else if ((this.defaultValue != null)) {
                resultingExpression = this.defaultValue;
            }

        }

        if ((resultingExpression != null)) {
            return resultingExpression.resolve(expressionData, resolved, undefined);
        }
        else {
            resolved.resolved = false;
            return value;
        }

    }
}

==> makeen-expressionengine-0.0.63.tgz: package/src/compiler/parts/switchPartData.ts <==
import { expressionPart } from "./expressionPart";
import expressionData from "../../expressionData";
import { utils } from "../utils";
import { outputVariables } from "../../utils/outputVariables";
export interface switchExpressionPart {
    key: expressionPart;
    value: expressionPart;
}
export class switchPartData {

    private cases: switchExpressionPart[] = [];

    get Cases(): switchExpressionPart[] {
        return this.cases;
    }

    private defaultValue!: expressionPart;

    get DefaultValue(): expressionPart {
        return this.defaultValue;
    }
    set DefaultValue(value: expressionPart) {
        this.defaultValue = value;
    }

    private nullValue!: expressionPart;

    get NullValue(): expressionPart {
        return this.nullValue;
    }
    set NullValue(value: expressionPart) {
        this.nullValue = value;
    }

    forValue(expressionData: expressionData, value: Object, resolved: outputVariables): Object | undefined {
        resolved.resolved = true;
        let resultingExpression!: expressionPart;
        if ((value === null || value === undefined)) {
            if ((this.nullValue != null)) {
                resultingExpression = this.nullValue;
            }
            else if ((this.defaultValue != null)) {
                resultingExpression = this.defaultValue;
            }

        }
        else {
            let matched!: expressionPart;
            this.cases.forEach((keyPart) => {
                let subResolved: outputVariables = new outputVariables();
                const reKey = (keyPart as switchExpressionPart).key;
                let key: Object = reKey.resolve(expressionData, subResolved, undefined) as Object;
                if ((subResolved.resolved
                    && ((key != null)
                        && utils.compare(key, value, '=')))) {
                    matched = keyPart.key;
                }
            });

            if ((matched != null)) {
                resultingExpression = this.cases.find((f) => f.key === matched)?.value as expressionPart;
            }
            else if ((this.defaultValue != null)) {
                resultingExpression = this.defaultValue;
            }

        }

        if ((resultingExpression != null)) {
            return resultingExpression.resolve(expressionData, resolved, undefined);
        }
        else {
            resolved.resolved = false;
            return value;
        }

    }
}
